@@ -31,6 +31,19 @@ from traceback import format_exc
 from collections import Mapping
 
 
+def get_running_servers():
+    temp_list = []
+    try:
+        honeypots = ['QDNSServer','QFTPServer','QHTTPProxyServer','QHTTPServer','QHTTPSServer','QIMAPServer','QMysqlServer','QPOP3Server','QPostgresServer','QRedisServer','QSMBServer','QSMTPServer','QSOCKS5Server','QSSHServer','QTelnetServer','QVNCServer']
+        for process in process_iter():
+            cmdline = ' '.join(process.cmdline())
+            for honeypot in honeypots: 
+                if '--custom' in cmdline and honeypot in cmdline:
+                    temp_list.append(cmdline.split(" --custom ")[1])
+    except BaseException:
+        pass
+    return temp_list
+
 def disable_logger(logger_type, object):
     if logger_type == 1:
         temp_name = path.join(gettempdir(), next(_get_candidate_names()))
@@ -53,7 +66,7 @@ def setup_logger(temp_name, config, drop=False):
     file_handler = None
     ret_logs_obj = getLogger(temp_name)
     ret_logs_obj.setLevel(DEBUG)
-    if logs == 'terminal' or logs == 'db' or logs == "all" or logs == '':
+    if 'terminal' in logs or 'db' in logs or 'all' in logs or logs == '':
         if 'db' in logs or 'all' in logs:
             ret_logs_obj.addHandler(CustomHandler(temp_name, logs, config_data, drop))
         if 'terminal' in logs or 'all' in logs or logs == '':
