@@ -14,133 +14,138 @@ from socks5_server import QSOCKS5Server
 from ssh_server import QSSHServer
 from telnet_server import QTelnetServer
 from vnc_server import QVNCServer
-from helper import server_arguments,clean_all
 from time import sleep
 
-print("Testing QDNSServer")
-qdnsserver = QDNSServer()
-qdnsserver.run_server(process=True,auto=True)
-sleep(1)
-qdnsserver.test_server()
-qdnsserver.kill_server()
-clean_all()
-
 print("Testing QFTPServer")
 qftpserver = QFTPServer()
-qftpserver.run_server(process=True,auto=True)
+qftpserver.run_server(process=True, auto=True)
 sleep(1)
 qftpserver.test_server()
 qftpserver.kill_server()
-clean_all()
+
+print("Testing QDNSServer")
+qdnsserver = QDNSServer()
+qdnsserver.run_server(process=True, auto=True)
+sleep(1)
+qdnsserver.test_server()
+qdnsserver.kill_server()
+
+
+print("Testing QFTPServer")
+qftpserver = QFTPServer()
+qftpserver.run_server(process=True, auto=True)
+sleep(1)
+qftpserver.test_server()
+qftpserver.kill_server()
+
 
 print("Testing QHTTPProxyServer")
 qhttpproxyserver = QHTTPProxyServer()
-qhttpproxyserver.run_server(process=True,auto=True)
+qhttpproxyserver.run_server(process=True, auto=True)
 sleep(1)
 qhttpproxyserver.test_server()
 qhttpproxyserver.kill_server()
-clean_all()
+
 
 print("Testing QHTTPServer")
 qhttpserver = QHTTPServer()
-qhttpserver.run_server(process=True,auto=True)
+qhttpserver.run_server(process=True, auto=True)
 sleep(1)
 qhttpserver.test_server()
 qhttpserver.kill_server()
-clean_all()
+
 
 print("Testing QHTTPSServer")
 qhttpsserver = QHTTPSServer()
-qhttpsserver.run_server(process=True,auto=True)
+qhttpsserver.run_server(process=True, auto=True)
 sleep(1)
 qhttpsserver.test_server()
 qhttpsserver.kill_server()
-clean_all()
+
 
 print("Testing QIMAPServer")
 qimapserver = QIMAPServer()
-qimapserver.run_server(process=True,auto=True)
+qimapserver.run_server(process=True, auto=True)
 sleep(1)
 qimapserver.test_server()
 qimapserver.kill_server()
-clean_all()
+
 
 print("Testing QMysqlServer")
 qmysqlserver = QMysqlServer()
-qmysqlserver.run_server(process=True,auto=True)
+qmysqlserver.run_server(process=True, auto=True)
 sleep(1)
 qmysqlserver.test_server()
 qmysqlserver.kill_server()
-clean_all()
+
 
 print("Testing QTPOP3Server")
 qpop3server = QPOP3Server()
-qpop3server.run_server(process=True,auto=True)
+qpop3server.run_server(process=True, auto=True)
 sleep(1)
 qpop3server.test_server()
 qpop3server.kill_server()
-clean_all()
+
 
 print("Testing QPostgresServer")
 qpostgresserver = QPostgresServer()
-qpostgresserver.run_server(process=True,auto=True)
+qpostgresserver.run_server(process=True, auto=True)
 sleep(1)
 qpostgresserver.test_server()
 qpostgresserver.kill_server()
-clean_all()
+
 
 print("Testing QRedisServer")
 qredisserver = QRedisServer()
-qredisserver.run_server(process=True,auto=True)
+qredisserver.run_server(process=True, auto=True)
 sleep(1)
 qredisserver.test_server()
 qredisserver.kill_server()
-clean_all()
+
 
 print("Testing QSMBServer")
 qsmbserver = QSMBServer()
-qsmbserver.run_server(process=True,auto=True)
+qsmbserver.run_server(process=True, auto=True)
 sleep(1)
 qsmbserver.test_server()
 qsmbserver.kill_server()
-clean_all()
+
 
 print("Testing QSMTPServer")
 qsmtpserver = QSMTPServer()
-qsmtpserver.run_server(process=True,auto=True)
+qsmtpserver.run_server(process=True, auto=True)
 sleep(1)
 qsmtpserver.test_server()
 qsmtpserver.kill_server()
-clean_all()
+
 
 print("Testing QSOCKS5Server")
 qsocks5server = QSOCKS5Server()
-qsocks5server.run_server(process=True,auto=True)
+qsocks5server.run_server(process=True, auto=True)
 sleep(1)
 qsocks5server.test_server()
 qsocks5server.kill_server()
-clean_all()
+
 
 print("Testing QSSHServer")
 qsshserver = QSSHServer()
-qsshserver.run_server(process=True,auto=True)
+qsshserver.run_server(process=True, auto=True)
 sleep(1)
 qsshserver.test_server()
 qsshserver.kill_server()
-clean_all()
+
 
 print("Testing QTelnetServer")
 qtelnetserver = QTelnetServer()
-qtelnetserver.run_server(process=True,auto=True)
+qtelnetserver.run_server(process=True, auto=True)
 sleep(1)
 qtelnetserver.test_server()
 qtelnetserver.kill_server()
-clean_all()
+
 
 print("Testing QVNCServer")
 qvncserver = QVNCServer()
-qvncserver.run_server(process=True,auto=True)
+qvncserver.run_server(process=True, auto=True)
 sleep(1)
 qvncserver.test_server()
 qvncserver.kill_server()
-clean_all()
